@@ -23,4 +23,5 @@ K_B = np.float64(8.617330337217213e-05)
 RY_TO_EV = np.float64(13.605693012183622)
 RY_PER_BOHR3_TO_GPA = 14710.513242194795
 RY_PER_BOHR3_TO_EV_PER_A3 = 91.81576765360094
-
+RY_TO_KELVIN = RY_TO_EV / K_B
+GPA_TO_EV_PER_A3 = RY_PER_BOHR3_TO_EV_PER_A3 / RY_PER_BOHR3_TO_GPA
